@@ -1,4 +1,4 @@
 from .client import Spotify
 
 
-__all__ = [Spotify]
+__all__ = ["Spotify"]
